
package Google::Ads::AdWords::v201206::TypeMaps::CampaignService;
use strict;
use warnings;

our $typemap_1 = {
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201206::EntityNotFound::Reason',
               'mutateResponse/rval/partialFailureErrors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors' => 'Google::Ads::AdWords::v201206::ApiError',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]' => 'Google::Ads::AdWords::v201206::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/status' => 'Google::Ads::AdWords::v201206::CampaignStatus',
               'mutateResponse/rval/value/campaignStats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]' => 'Google::Ads::AdWords::v201206::BiddingError',
               'mutateResponse/rval/partialFailureErrors[AdxError]' => 'Google::Ads::AdWords::v201206::AdxError',
               'mutateResponse/rval/value/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting',
               'mutate/operations/operand/campaignStats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201206::Predicate',
               'mutate/operations/operand/campaignStats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201206::NotEmptyError::Reason',
               'mutateResponse/rval/partialFailureErrors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[ConversionOptimizer]' => 'Google::Ads::AdWords::v201206::ConversionOptimizer',
               'getResponse/rval/totalBudget/period' => 'Google::Ads::AdWords::v201206::Budget::BudgetPeriod',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[ManualCPM]' => 'Google::Ads::AdWords::v201206::ManualCPM',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201206::StatsQueryError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201206::RateExceededError::Reason',
               'getResponse/rval/entries/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[RejectedError]' => 'Google::Ads::AdWords::v201206::RejectedError',
               'mutate/operations/operand/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[ManualCPC]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/settings[TargetRestrictSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/biddingStrategy[ConversionOptimizer]' => 'Google::Ads::AdWords::v201206::ConversionOptimizer',
               'mutateResponse/rval/value/biddingStrategy[PercentCPA]' => 'Google::Ads::AdWords::v201206::PercentCPA',
               'mutate/operations/operand/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201206::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201206::Paging',
               'mutateResponse/rval/partialFailureErrors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201206::NewEntityCreationError',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201206::Campaign',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201206::CampaignStatus',
               'getResponse/rval/entries/budget/deliveryMethod' => 'Google::Ads::AdWords::v201206::Budget::BudgetDeliveryMethod',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]' => 'Google::Ads::AdWords::v201206::EntityNotFound',
               'getResponse/rval/entries/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]' => 'Google::Ads::AdWords::v201206::ClientTermsError',
               'mutate/operations/operand/biddingStrategy[ManualCPC]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignError]/reason' => 'Google::Ads::AdWords::v201206::CampaignError::Reason',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/BiddingTransition.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/cost' => 'Google::Ads::AdWords::v201206::Money',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::NegativeGeoTargetType',
               'mutateResponse/rval/value/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/biddingStrategy[BudgetOptimizer]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/networkSetting/targetContentContextual' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/biddingStrategy[ConversionOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/totalBudget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201206::Predicate::Operator',
               'mutateResponse/rval/partialFailureErrors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[TargetRestrictSetting]/useAdGroup' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::NegativeGeoTargetType',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BudgetError]' => 'Google::Ads::AdWords::v201206::BudgetError',
               'Fault/detail/ApiExceptionFault/errors[TargetError]' => 'Google::Ads::AdWords::v201206::TargetError',
               'mutateResponse/rval/partialFailureErrors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[BudgetOptimizer]' => 'Google::Ads::AdWords::v201206::BudgetOptimizer',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201206::OperationAccessDenied',
               'queryResponse/rval/entries/biddingStrategy[ManualCPM]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[BudgetOptimizer]/bidCeiling' => 'Google::Ads::AdWords::v201206::Money',
               'queryResponse/rval/entries/biddingStrategy[ManualCPC]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy' => 'Google::Ads::AdWords::v201206::BiddingStrategy',
               'getResponse/rval/entries/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::PositiveGeoTargetType',
               'getResponse/rval/entries/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/biddingStrategy[ManualCPC]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201206::QueryError',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201206::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201206::BetaError',
               'getResponse/rval/totalBudget/deliveryMethod' => 'Google::Ads::AdWords::v201206::Budget::BudgetDeliveryMethod',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201206::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::NegativeGeoTargetType',
               'mutateResponse/rval/value/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/totalBudget' => 'Google::Ads::AdWords::v201206::Budget',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ConversionOptimizer]' => 'Google::Ads::AdWords::v201206::ConversionOptimizer',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/reason' => 'Google::Ads::AdWords::v201206::RejectedError::Reason',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/reason' => 'Google::Ads::AdWords::v201206::CampaignError::Reason',
               'mutate/operations/operand/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201206::KeywordMatchSetting',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/reason' => 'Google::Ads::AdWords::v201206::RequiredError::Reason',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/campaignStats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[UnknownBiddingStrategy]' => 'Google::Ads::AdWords::v201206::UnknownBiddingStrategy',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingStrategy[ConversionOptimizer]/deduplicationMode' => 'Google::Ads::AdWords::v201206::ConversionDeduplicationMode',
               'mutate/operations/operand/networkSetting' => 'Google::Ads::AdWords::v201206::NetworkSetting',
               'queryResponse/rval/entries/campaignStats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[PercentCPA]' => 'Google::Ads::AdWords::v201206::PercentCPA',
               'queryResponse/rval/entries/campaignStats/cost' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201206::StringLengthError::Reason',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/biddingStrategy[ManualCPC]' => 'Google::Ads::AdWords::v201206::ManualCPC',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201206::StatsQueryError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201206::AdServingOptimizationStatus',
               'mutate/operations/operand/biddingStrategy[ConversionOptimizer]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBidType',
               'queryResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/campaignStats' => 'Google::Ads::AdWords::v201206::CampaignStats',
               'mutate/operations/operand/campaignStats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201206::InternalApiError::Reason',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201206::EntityCountLimitExceeded',
               'queryResponse/rval/entries/servingStatus' => 'Google::Ads::AdWords::v201206::ServingStatus',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201206::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201206::DatabaseError::Reason',
               'queryResponse/rval/entries/budget/period' => 'Google::Ads::AdWords::v201206::Budget::BudgetPeriod',
               'mutate/operations/operand/biddingStrategy[BudgetOptimizer]/bidCeiling' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/value/biddingStrategy/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[TargetRestrictSetting]' => 'Google::Ads::AdWords::v201206::TargetRestrictSetting',
               'mutate/operations/operand/budget/deliveryMethod' => 'Google::Ads::AdWords::v201206::Budget::BudgetDeliveryMethod',
               'getResponse/rval/entries/biddingStrategy[ConversionOptimizer]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBidType',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201206::DateError',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]' => 'Google::Ads::AdWords::v201206::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201206::ClientTermsError::Reason',
               'queryResponse/rval/totalBudget/period' => 'Google::Ads::AdWords::v201206::Budget::BudgetPeriod',
               'mutateResponse/rval/partialFailureErrors[NullError]/reason' => 'Google::Ads::AdWords::v201206::NullError::Reason',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201206::InternalApiError',
               'queryResponse/rval/entries/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility::RejectionReason',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/averageCpm' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/value/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition' => 'Google::Ads::AdWords::v201206::BiddingTransition',
               'mutateResponse/rval/partialFailureErrors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[BudgetOptimizer]' => 'Google::Ads::AdWords::v201206::BudgetOptimizer',
               'getResponse/rval/entries/settings[KeywordMatchSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[TargetError]' => 'Google::Ads::AdWords::v201206::TargetError',
               'queryResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/campaignStats/cost' => 'Google::Ads::AdWords::v201206::Money',
               'getResponse/rval/entries/campaignStats/cost' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/campaignStats/network' => 'Google::Ads::AdWords::v201206::Stats::Network',
               'mutateResponse/rval/value/biddingStrategy[ConversionOptimizer]' => 'Google::Ads::AdWords::v201206::ConversionOptimizer',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'mutate/operations/operand/frequencyCap/level' => 'Google::Ads::AdWords::v201206::Level',
               'mutate/operations/operand/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility::RejectionReason',
               'mutateResponse/rval/value/biddingStrategy[ManualCPC]' => 'Google::Ads::AdWords::v201206::ManualCPC',
               'mutate/operations/operand/settings' => 'Google::Ads::AdWords::v201206::Setting',
               'getResponse/rval/entries/budget' => 'Google::Ads::AdWords::v201206::Budget',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse' => 'Google::Ads::AdWords::v201206::CampaignService::getResponse',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201206::StatsQueryError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]' => 'Google::Ads::AdWords::v201206::BiddingError',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/reason' => 'Google::Ads::AdWords::v201206::DistinctError::Reason',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201206::CampaignPage',
               'mutate/operations/operand/budget' => 'Google::Ads::AdWords::v201206::Budget',
               'getResponse/rval/entries/campaignStats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201206::ClientTermsError',
               'queryResponse/rval/entries/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/averageCpm' => 'Google::Ads::AdWords::v201206::Money',
               'mutate/operations/operand/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[PercentCPA]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[TargetRestrictSetting]/useAdGroup' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/biddingStrategy[BudgetOptimizer]' => 'Google::Ads::AdWords::v201206::BudgetOptimizer',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/reason' => 'Google::Ads::AdWords::v201206::OperatorError::Reason',
               'queryResponse/rval/entries/campaignStats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QueryError]/reason' => 'Google::Ads::AdWords::v201206::QueryError::Reason',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[BudgetOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/budget/period' => 'Google::Ads::AdWords::v201206::Budget::BudgetPeriod',
               'getResponse/rval/entries/biddingStrategy[ConversionOptimizer]/pricingModel' => 'Google::Ads::AdWords::v201206::PricingModel',
               'mutate/operations/operand/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201206::AdServingOptimizationStatus',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[ManualCPC]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/biddingStrategy[ManualCPM]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats' => 'Google::Ads::AdWords::v201206::CampaignStats',
               'mutate/operations/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[UnknownBiddingStrategy]' => 'Google::Ads::AdWords::v201206::UnknownBiddingStrategy',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[TargetError]/reason' => 'Google::Ads::AdWords::v201206::TargetError::Reason',
               'mutateResponse/rval/partialFailureErrors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201206::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]' => 'Google::Ads::AdWords::v201206::RequiredError',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201206::Campaign',
               'mutate/operations/operand/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]' => 'Google::Ads::AdWords::v201206::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/averageCpc' => 'Google::Ads::AdWords::v201206::Money',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/reason' => 'Google::Ads::AdWords::v201206::BudgetError::Reason',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201206::InternalApiError::Reason',
               'queryResponse/rval/entries/networkSetting' => 'Google::Ads::AdWords::v201206::NetworkSetting',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ManualCPM]' => 'Google::Ads::AdWords::v201206::ManualCPM',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201206::RejectedError::Reason',
               'mutateResponse/rval/value/biddingStrategy[BudgetOptimizer]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[BudgetOptimizer]/bidCeiling' => 'Google::Ads::AdWords::v201206::Money',
               'queryResponse/rval/entries/campaignStats/averageCpc' => 'Google::Ads::AdWords::v201206::Money',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/campaignStats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/totalBudget/amount' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201206::AdServingOptimizationStatus',
               'mutateResponse/rval/value/campaignStats/network' => 'Google::Ads::AdWords::v201206::Stats::Network',
               'mutate/operations/operand/campaignStats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201206::SelectorError::Reason',
               'mutateResponse/rval/partialFailureErrors[DateError]/reason' => 'Google::Ads::AdWords::v201206::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201206::DatabaseError',
               'queryResponse/rval/entries/biddingStrategy[BudgetOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201206::AuthorizationError',
               'mutate/operations/operand/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/campaignStats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[ManualCPM]' => 'Google::Ads::AdWords::v201206::ManualCPM',
               'mutateResponse/rval/partialFailureErrors[RequestError]/reason' => 'Google::Ads::AdWords::v201206::RequestError::Reason',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/campaignStats/averageCpm' => 'Google::Ads::AdWords::v201206::Money',
               'queryResponse/rval/entries/budget/deliveryMethod' => 'Google::Ads::AdWords::v201206::Budget::BudgetDeliveryMethod',
               'mutateResponse/rval/value/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201206::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[GeoTargetTypeSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings' => 'Google::Ads::AdWords::v201206::Setting',
               'queryResponse/rval/entries/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201206::KeywordMatchSetting',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/reason' => 'Google::Ads::AdWords::v201206::AdxError::Reason',
               'getResponse/rval/entries/campaignStats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/campaignStats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'query' => 'Google::Ads::AdWords::v201206::CampaignService::query',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201206::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ConversionOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[TargetRestrictSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]' => 'Google::Ads::AdWords::v201206::NotEmptyError',
               'mutateResponse/rval/partialFailureErrors[RequestError]' => 'Google::Ads::AdWords::v201206::RequestError',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ManualCPC]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'getResponse/rval/entries/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SettingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[ConversionOptimizer]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBidType',
               'queryResponse' => 'Google::Ads::AdWords::v201206::CampaignService::queryResponse',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[UnknownBiddingStrategy]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/networkSetting/targetSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/campaignStats' => 'Google::Ads::AdWords::v201206::CampaignStats',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]' => 'Google::Ads::AdWords::v201206::AuthorizationError',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201206::CampaignStatus',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[BudgetOptimizer]/bidCeiling' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201206::NewEntityCreationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RangeError]/reason' => 'Google::Ads::AdWords::v201206::RangeError::Reason',
               'getResponse/rval/entries/campaignStats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingStrategy/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201206::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201206::NotWhitelistedError::Reason',
               'mutateResponse/rval/partialFailureErrors[SettingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignError]' => 'Google::Ads::AdWords::v201206::CampaignError',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ManualCPC]' => 'Google::Ads::AdWords::v201206::ManualCPC',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy' => 'Google::Ads::AdWords::v201206::BiddingStrategy',
               'getResponse/rval/entries/biddingStrategy[ManualCPM]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[BudgetOptimizer]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[UnknownBiddingStrategy]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[TargetRestrictSetting]/useAdGroup' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/biddingStrategy[PercentCPA]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[BudgetOptimizer]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/budget/deliveryMethod' => 'Google::Ads::AdWords::v201206::Budget::BudgetDeliveryMethod',
               'getResponse/rval/entries/campaignStats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]' => 'Google::Ads::AdWords::v201206::NullError',
               'mutateResponse/rval/partialFailureErrors[BetaError]' => 'Google::Ads::AdWords::v201206::BetaError',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]' => 'Google::Ads::AdWords::v201206::StringLengthError',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]' => 'Google::Ads::AdWords::v201206::QuotaError',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201206::ApiException',
               'mutateResponse/rval/partialFailureErrors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/network' => 'Google::Ads::AdWords::v201206::Stats::Network',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SelectorError]/reason' => 'Google::Ads::AdWords::v201206::SelectorError::Reason',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201206::RangeError::Reason',
               'getResponse/rval/entries/campaignStats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[BudgetOptimizer]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/biddingStrategy/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/useSavedBids' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201206::ReadOnlyError',
               'mutateResponse/rval/value/biddingStrategy[ManualCPM]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201206::RequestError',
               'mutate/operations/operand/biddingStrategy[ConversionOptimizer]' => 'Google::Ads::AdWords::v201206::ConversionOptimizer',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201206::RequiredError',
               'mutateResponse/rval/value/campaignStats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[PercentCPA]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[BudgetOptimizer]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]' => 'Google::Ads::AdWords::v201206::StatsQueryError',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201206::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201206::NotEmptyError',
               'mutateResponse/rval/value/budget/period' => 'Google::Ads::AdWords::v201206::Budget::BudgetPeriod',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ConversionOptimizer]/pricingModel' => 'Google::Ads::AdWords::v201206::PricingModel',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[PercentCPA]' => 'Google::Ads::AdWords::v201206::PercentCPA',
               'queryResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[PercentCPA]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ConversionOptimizer]/deduplicationMode' => 'Google::Ads::AdWords::v201206::ConversionDeduplicationMode',
               'mutateResponse/rval/partialFailureErrors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201206::KeywordMatchSetting',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/BiddingTransition.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/campaignStats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/campaignStats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/biddingTransition/targetBiddingStrategy/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/frequencyCap/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingStrategy[ConversionOptimizer]/deduplicationMode' => 'Google::Ads::AdWords::v201206::ConversionDeduplicationMode',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy' => 'Google::Ads::AdWords::v201206::BiddingStrategy',
               'getResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]' => 'Google::Ads::AdWords::v201206::UnknownBiddingStrategy',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201206::EntityCountLimitExceeded::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'mutateResponse/rval/value/biddingStrategy[UnknownBiddingStrategy]' => 'Google::Ads::AdWords::v201206::UnknownBiddingStrategy',
               'getResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[BudgetOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201206::AuthenticationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[RangeError]' => 'Google::Ads::AdWords::v201206::RangeError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ManualCPM]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]' => 'Google::Ads::AdWords::v201206::QueryError',
               'queryResponse/rval/entries/budget' => 'Google::Ads::AdWords::v201206::Budget',
               'getResponse/rval/entries/frequencyCap/level' => 'Google::Ads::AdWords::v201206::Level',
               'mutateResponse/rval/partialFailureErrors[TargetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/budget/amount' => 'Google::Ads::AdWords::v201206::Money',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[BudgetOptimizer]' => 'Google::Ads::AdWords::v201206::BudgetOptimizer',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201206::StringLengthError::Reason',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse' => 'Google::Ads::AdWords::v201206::CampaignService::mutateResponse',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201206::AdxError',
               'mutate/operations/operand/campaignStats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/reason' => 'Google::Ads::AdWords::v201206::SettingError::Reason',
               'mutateResponse/rval/value/settings[TargetRestrictSetting]' => 'Google::Ads::AdWords::v201206::TargetRestrictSetting',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201206::DatabaseError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/frequencyCap' => 'Google::Ads::AdWords::v201206::FrequencyCap',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ManualCPM]' => 'Google::Ads::AdWords::v201206::ManualCPM',
               'mutateResponse/rval/value/frequencyCap/level' => 'Google::Ads::AdWords::v201206::Level',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201206::OperatorError::Reason',
               'mutateResponse/rval/partialFailureErrors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings' => 'Google::Ads::AdWords::v201206::Setting',
               'mutateResponse/rval/partialFailureErrors[TargetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201206::OperationAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ManualCPM]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SettingError]' => 'Google::Ads::AdWords::v201206::SettingError',
               'mutateResponse/rval/partialFailureErrors[BetaError]/reason' => 'Google::Ads::AdWords::v201206::BetaError::Reason',
               'mutateResponse/rval/partialFailureErrors[BiddingTransitionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SettingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201206::EntityCountLimitExceeded::Reason',
               'getResponse/rval/entries/biddingStrategy[ManualCPC]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[ConversionOptimizer]/pricingModel' => 'Google::Ads::AdWords::v201206::PricingModel',
               'queryResponse/rval/entries/biddingStrategy/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/frequencyCap/level' => 'Google::Ads::AdWords::v201206::Level',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201206::NewEntityCreationError',
               'mutateResponse/rval/partialFailureErrors[BudgetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaError]/reason' => 'Google::Ads::AdWords::v201206::QuotaError::Reason',
               'queryResponse/rval/entries/biddingStrategy[BudgetOptimizer]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201206::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201206::SortOrder',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201206::CampaignService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'getResponse/rval/entries/biddingStrategy[BudgetOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[BudgetOptimizer]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[UnknownBiddingStrategy]' => 'Google::Ads::AdWords::v201206::UnknownBiddingStrategy',
               'getResponse/rval/entries/frequencyCap' => 'Google::Ads::AdWords::v201206::FrequencyCap',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201206::BetaError::Reason',
               'queryResponse/rval/totalBudget/amount' => 'Google::Ads::AdWords::v201206::Money',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201206::QuotaCheckError',
               'mutateResponse/rval/partialFailureErrors[TargetError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[ConversionOptimizer]/pricingModel' => 'Google::Ads::AdWords::v201206::PricingModel',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/biddingStrategy[ConversionOptimizer]/pricingModel' => 'Google::Ads::AdWords::v201206::PricingModel',
               'getResponse/rval/entries/adServingOptimizationStatus' => 'Google::Ads::AdWords::v201206::AdServingOptimizationStatus',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/totalBudget' => 'Google::Ads::AdWords::v201206::Budget',
               'getResponse/rval/entries/settings[TargetRestrictSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::PositiveGeoTargetType',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/networkSetting/targetContentContextual' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201206::TimeUnit',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]' => 'Google::Ads::AdWords::v201206::BudgetError',
               'mutateResponse/rval/value/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/settings[GeoTargetTypeSetting]/negativeGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::NegativeGeoTargetType',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[BudgetOptimizer]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201206::BiddingTransitionError',
               'mutateResponse/rval/partialFailureErrors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ManualCPC]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBiddingTransition',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/campaignStats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201206::SizeLimitError::Reason',
               'mutateResponse/rval/value/campaignStats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/biddingTransition/targetBiddingStrategy[PercentCPA]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/campaignStats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201206::StringLengthError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201206::AuthenticationError::Reason',
               'getResponse/rval/entries/budget/amount' => 'Google::Ads::AdWords::v201206::Money',
               'getResponse/rval/entries/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting',
               'mutateResponse/rval/value/biddingStrategy[BudgetOptimizer]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SettingError]/reason' => 'Google::Ads::AdWords::v201206::SettingError::Reason',
               'mutateResponse/rval/value/budget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201206::EntityNotFound',
               'getResponse/rval/entries/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility',
               'mutate/operations/operand/budget/period' => 'Google::Ads::AdWords::v201206::Budget::BudgetPeriod',
               'mutateResponse/rval/partialFailureErrors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201206::TimeUnit',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201206::QueryError::Reason',
               'mutate/operations/operand/biddingStrategy[BudgetOptimizer]' => 'Google::Ads::AdWords::v201206::BudgetOptimizer',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201206::CampaignStatus',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201206::EntityNotFound::Reason',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ConversionOptimizer]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBidType',
               'mutateResponse/rval/partialFailureErrors[BiddingTransitionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201206::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]' => 'Google::Ads::AdWords::v201206::QuotaCheckError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingTransitionError]' => 'Google::Ads::AdWords::v201206::BiddingTransitionError',
               'mutateResponse/rval/partialFailureErrors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201206::NotWhitelistedError::Reason',
               'getResponse/rval/entries/campaignStats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/reason' => 'Google::Ads::AdWords::v201206::BiddingError::Reason',
               'queryResponse/rval/entries/biddingStrategy[PercentCPA]' => 'Google::Ads::AdWords::v201206::PercentCPA',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[BudgetOptimizer]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SettingError]' => 'Google::Ads::AdWords::v201206::SettingError',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ConversionOptimizer]' => 'Google::Ads::AdWords::v201206::ConversionOptimizer',
               'mutateResponse/rval/value/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201206::QuotaError::Reason',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201206::BiddingTransitionError::Reason',
               'mutateResponse/rval/value/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201206::NullError',
               'queryResponse/rval/entries/campaignStats/network' => 'Google::Ads::AdWords::v201206::Stats::Network',
               'mutate/operations/operand/campaignStats/averageCpc' => 'Google::Ads::AdWords::v201206::Money',
               'queryResponse/rval/totalBudget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]' => 'Google::Ads::AdWords::v201206::UnknownBiddingStrategy',
               'mutateResponse/rval/value/budget' => 'Google::Ads::AdWords::v201206::Budget',
               'getResponse/rval/entries/campaignStats' => 'Google::Ads::AdWords::v201206::CampaignStats',
               'mutate/operations/biddingTransition/targetBiddingStrategy' => 'Google::Ads::AdWords::v201206::BiddingStrategy',
               'mutateResponse/rval/partialFailureErrors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[TargetError]/reason' => 'Google::Ads::AdWords::v201206::TargetError::Reason',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201206::TimeUnit',
               'mutate/operations/biddingTransition/targetBiddingStrategy[PercentCPA]' => 'Google::Ads::AdWords::v201206::PercentCPA',
               'mutateResponse/rval/partialFailureErrors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201206::CampaignPage',
               'getResponse/rval/entries/networkSetting/targetPartnerSearchNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/networkSetting/targetContentContextual' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ConversionOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[BudgetOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/biddingStrategy[ConversionOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/networkSetting' => 'Google::Ads::AdWords::v201206::NetworkSetting',
               'mutate/operations/operand/campaignStats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[UnknownBiddingStrategy]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/servingStatus' => 'Google::Ads::AdWords::v201206::ServingStatus',
               'queryResponse/rval/entries/campaignStats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]' => 'Google::Ads::AdWords::v201206::AuthenticationError',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201206::NotEmptyError::Reason',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[BudgetOptimizer]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[TargetRestrictSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[TargetRestrictSetting]' => 'Google::Ads::AdWords::v201206::TargetRestrictSetting',
               'queryResponse/rval/entries/biddingStrategy[ManualCPC]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201206::QuotaCheckError::Reason',
               'mutateResponse/rval/value/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility::RejectionReason',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[BudgetOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[ManualCPM]' => 'Google::Ads::AdWords::v201206::ManualCPM',
               'getResponse/rval/entries/campaignStats/averageCpc' => 'Google::Ads::AdWords::v201206::Money',
               'getResponse/rval/entries/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ConversionOptimizer]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBidType',
               'queryResponse/rval/entries/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201206::RealTimeBiddingSetting',
               'mutateResponse/rval/partialFailureErrors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ConversionOptimizer]/deduplicationMode' => 'Google::Ads::AdWords::v201206::ConversionDeduplicationMode',
               'queryResponse/rval/entries/settings[TargetRestrictSetting]/useAdGroup' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/settings' => 'Google::Ads::AdWords::v201206::Setting',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201206::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/totalBudget/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/networkSetting/targetContentContextual' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[DateError]' => 'Google::Ads::AdWords::v201206::DateError',
               'mutate/operations/operand/biddingStrategy[ConversionOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[BudgetOptimizer]/bidCeiling/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201206::OrderBy',
               'queryResponse/rval/entries/budget/amount' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]' => 'Google::Ads::AdWords::v201206::OperatorError',
               'getResponse/rval/entries/biddingStrategy[BudgetOptimizer]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/campaignStats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201206::NotWhitelistedError',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[ManualCPM]' => 'Google::Ads::AdWords::v201206::ManualCPM',
               'mutateResponse/rval/value/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/campaignStats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/networkSetting/targetContentNetwork' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201206::RequiredError::Reason',
               'getResponse/rval/entries/campaignStats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/servingStatus' => 'Google::Ads::AdWords::v201206::ServingStatus',
               'queryResponse/rval/entries/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201206::AdxError::Reason',
               'mutateResponse/rval/partialFailureErrors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BudgetError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'mutateResponse/rval/value/biddingStrategy[ConversionOptimizer]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201206::ConversionOptimizerBidType',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201206::ReadOnlyError::Reason',
               'mutate/operations/operand/frequencyCap/timeUnit' => 'Google::Ads::AdWords::v201206::TimeUnit',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201206::NullError::Reason',
               'Fault/detail/ApiExceptionFault/errors[CampaignError]' => 'Google::Ads::AdWords::v201206::CampaignError',
               'queryResponse/rval/entries/settings/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[BudgetOptimizer]/bidCeiling/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/totalBudget/deliveryMethod' => 'Google::Ads::AdWords::v201206::Budget::BudgetDeliveryMethod',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[ManualCPC]' => 'Google::Ads::AdWords::v201206::ManualCPC',
               'mutateResponse/rval/partialFailureErrors[BudgetError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201206::ApiError',
               'queryResponse/rval/entries/campaignStats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201206::RealTimeBiddingSetting',
               'mutate/operations/operand/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201206::RealTimeBiddingSetting',
               'getResponse/rval/entries/budget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/campaignStats/averageCpm' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/value/networkSetting' => 'Google::Ads::AdWords::v201206::NetworkSetting',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[UnknownBiddingStrategy]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::PositiveGeoTargetType',
               'queryResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate' => 'Google::Ads::AdWords::v201206::CampaignService::mutate',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ManualCPC]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy[BudgetOptimizer]' => 'Google::Ads::AdWords::v201206::BudgetOptimizer',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[RealTimeBiddingSetting]' => 'Google::Ads::AdWords::v201206::RealTimeBiddingSetting',
               'mutate/operations/operand/campaignStats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy[ManualCPC]' => 'Google::Ads::AdWords::v201206::ManualCPC',
               'mutate/operations/operand/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/budget/amount' => 'Google::Ads::AdWords::v201206::Money',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201206::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignStats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/settings[GeoTargetTypeSetting]/positiveGeoTargetType' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting::PositiveGeoTargetType',
               'queryResponse/rval/entries/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility',
               'getResponse/rval/entries/networkSetting/targetGoogleSearch' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap' => 'Google::Ads::AdWords::v201206::String_StringMapEntry',
               'mutateResponse/rval/partialFailureErrors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/frequencyCap' => 'Google::Ads::AdWords::v201206::FrequencyCap',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201206::RateExceededError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201206::BiddingError::Reason',
               'mutate/operations/operand/settings[KeywordMatchSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201206::ApiException',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201206::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/settings[RealTimeBiddingSetting]/Setting.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/biddingStrategy' => 'Google::Ads::AdWords::v201206::BiddingStrategy',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[PercentCPA]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/biddingStrategy' => 'Google::Ads::AdWords::v201206::BiddingStrategy',
               'mutateResponse/rval/value/servingStatus' => 'Google::Ads::AdWords::v201206::ServingStatus',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignStats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[ConversionOptimizer]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201206::EntityCountLimitExceeded',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201206::NotWhitelistedError',
               'getResponse/rval/entries/biddingStrategy[PercentCPA]' => 'Google::Ads::AdWords::v201206::PercentCPA',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201206::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201206::RequestError::Reason',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[BudgetOptimizer]/bidCeiling' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[BudgetOptimizer]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]' => 'Google::Ads::AdWords::v201206::InternalApiError',
               'mutateResponse/rval/partialFailureErrors[SelectorError]' => 'Google::Ads::AdWords::v201206::SelectorError',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/campaignStats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/biddingStrategy[BudgetOptimizer]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201206::OperationAccessDenied::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[BudgetError]/reason' => 'Google::Ads::AdWords::v201206::BudgetError::Reason',
               'mutateResponse/rval/value/biddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/key' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[ManualCPC]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[GeoTargetTypeSetting]' => 'Google::Ads::AdWords::v201206::GeoTargetTypeSetting',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[CampaignError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201206::CampaignReturnValue',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201206::OperationAccessDenied::Reason',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/biddingStrategy[ConversionOptimizer]/deduplicationMode' => 'Google::Ads::AdWords::v201206::ConversionDeduplicationMode',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]' => 'Google::Ads::AdWords::v201206::DatabaseError',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[ConversionOptimizer]/pricingModel' => 'Google::Ads::AdWords::v201206::PricingModel',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[TargetRestrictSetting]' => 'Google::Ads::AdWords::v201206::TargetRestrictSetting',
               'mutateResponse/rval/value/frequencyCap' => 'Google::Ads::AdWords::v201206::FrequencyCap',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201206::Campaign',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[TargetError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201206::RejectedError',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ManualCPC]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/biddingTransition/targetBiddingStrategy[ManualCPC]' => 'Google::Ads::AdWords::v201206::ManualCPC',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/biddingStrategy[ConversionOptimizer]/deduplicationMode' => 'Google::Ads::AdWords::v201206::ConversionDeduplicationMode',
               'queryResponse/rval/entries/campaignStats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201206::OperatorError',
               'mutateResponse/rval/value/conversionOptimizerEligibility' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201206::ClientTermsError::Reason',
               'mutate/operations/biddingTransition[ConversionOptimizerBiddingTransition]/targetBiddingStrategy[BudgetOptimizer]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/biddingStrategy[UnknownBiddingStrategy]/BiddingStrategy.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/totalBudget/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/biddingTransition/targetBiddingStrategy[BudgetOptimizer]/bidCeiling' => 'Google::Ads::AdWords::v201206::Money',
               'mutateResponse/rval/partialFailureErrors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201206::NewEntityCreationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BiddingTransitionError]/reason' => 'Google::Ads::AdWords::v201206::BiddingTransitionError::Reason',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201206::Selector',
               'getResponse/rval/entries/conversionOptimizerEligibility/rejectionReasons' => 'Google::Ads::AdWords::v201206::ConversionOptimizerEligibility::RejectionReason',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201206::Campaign',
               'mutate/operations/operand/campaignStats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/settings[KeywordMatchSetting]' => 'Google::Ads::AdWords::v201206::KeywordMatchSetting',
               'mutateResponse/rval/partialFailureErrors[DistinctError]' => 'Google::Ads::AdWords::v201206::DistinctError',
               'mutateResponse/rval/partialFailureErrors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/settings[RealTimeBiddingSetting]/optIn' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/biddingTransition/targetBiddingStrategy[UnknownBiddingStrategy]/forwardCompatibilityMap/value' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201206::SelectorError',
               'mutateResponse/rval/partialFailureErrors[QuotaError]' => 'Google::Ads::AdWords::v201206::QuotaError',
               'mutate/operations' => 'Google::Ads::AdWords::v201206::CampaignOperation',
               'mutate/operations/operand/conversionOptimizerEligibility/eligible' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201206::TypeMaps::CampaignService - typemap for CampaignService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

