
package Google::Ads::AdWords::v201109_1::TypeMaps::AdExtensionOverrideService;
use strict;
use warnings;

our $typemap_1 = {
               'mutate/operations/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[ProductExtension]/productSelection/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201109_1::EntityNotFound::Reason',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201109_1::OAuthInfo',
               'mutateResponse/rval/value/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[ProductExtension]/productSelection/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthenticationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201109_1::NotEmptyError::Reason',
               'getResponse/rval/entries/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[ProductExtension]/googleBaseCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo' => 'Google::Ads::AdWords::v201109_1::OverrideInfo',
               'mutateResponse/rval/value/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201109_1::StringLengthError::Reason',
               'mutateResponse/rval/value/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideError::Reason',
               'mutateResponse' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideService::mutateResponse',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201109_1::RateExceededError::Reason',
               'mutate/operations/operand/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201109_1::Sitelink',
               'getResponse/rval/entries/adExtension' => 'Google::Ads::AdWords::v201109_1::AdExtension',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthorizationError::Reason',
               'getResponse/rval/entries/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201109_1::LocationExtension::Source',
               'mutate/operations/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201109_1::SitelinksExtension',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201109_1::OperatorError::Reason',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::Status',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension[ProductExtension]/productSelection/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'get/selector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension[ProductExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201109_1::GeoPoint',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201109_1::Address',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'getResponse/rval/entries/adExtension[ProductExtension]/productSelection' => 'Google::Ads::AdWords::v201109_1::ProductConditionAndGroup',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/adExtension[ProductExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError',
               'getResponse/rval/entries/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201109_1::MobileExtension',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201109_1::GeoPoint',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201109_1::OAuthInfo',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[ProductExtension]' => 'Google::Ads::AdWords::v201109_1::ProductExtension',
               'getResponse/rval/entries/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201109_1::RateExceededError',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201109_1::LocationOverrideInfo::RadiusUnits',
               'mutateResponse/rval/value/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/adExtension[ProductExtension]/advertiserName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideStats',
               'get/selector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[ProductExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201109_1::LocationOverrideInfo::RadiusUnits',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201109_1::StringLengthError',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201109_1::Address',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201109_1::MobileExtension',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201109_1::EntityNotFound',
               'getResponse/rval/entries/stats' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideStats',
               'mutateResponse/rval/value/adExtension[ProductExtension]/productSelection/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[ProductExtension]/productSelection/conditions/operand' => 'Google::Ads::AdWords::v201109_1::ProductConditionOperand',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201109_1::SitelinksExtension',
               'getResponse/rval/entries/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::Status',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201109_1::DatabaseError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201109_1::DistinctError::Reason',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201109_1::ClientTermsError::Reason',
               'mutate/operations/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201109_1::InternalApiError',
               'getResponse/rval/entries/adExtension[ProductExtension]' => 'Google::Ads::AdWords::v201109_1::ProductExtension',
               'getResponse/rval/entries/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201109_1::LocationOverrideInfo',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[ProductExtension]/productSelection/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'getResponse/rval/entries/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201109_1::LocationExtension::Source',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201109_1::NullError',
               'getResponse/rval/entries/approvalStatus' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::ApprovalStatus',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideService::getResponse',
               'mutateResponse/rval/value/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[ProductExtension]/productSelection/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/campaignIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverridePage',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201109_1::ClientTermsError',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201109_1::LocationOverrideInfo',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[ProductExtension]' => 'Google::Ads::AdWords::v201109_1::ProductExtension',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/adIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201109_1::GeoPoint',
               'mutate/operations/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201109_1::Address',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201109_1::InternalApiError::Reason',
               'getResponse/rval/entries/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201109_1::Sitelink',
               'mutate/operations/operand/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[ProductExtension]/productSelection/conditions' => 'Google::Ads::AdWords::v201109_1::ProductCondition',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201109_1::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension[ProductExtension]/productSelection/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201109_1::LocationOverrideInfo::RadiusUnits',
               'mutate/operations/operand/adExtension[ProductExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError',
               'mutateResponse/rval/value/adExtension[ProductExtension]/googleBaseCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201109_1::DatabaseError',
               'mutate/operations/operand/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201109_1::AuthorizationError',
               'mutate/operations/operand/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideStats',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201109_1::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/paging' => 'Google::Ads::AdWords::v201109_1::Paging',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201109_1::LocationSyncExtension',
               'getResponse/rval/entries/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/statuses' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::Status',
               'getResponse/rval/entries/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201109_1::MobileExtension',
               'mutateResponse/rval/value/adExtension[ProductExtension]/productSelection' => 'Google::Ads::AdWords::v201109_1::ProductConditionAndGroup',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201109_1::Operator',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201109_1::LocationSyncExtension',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201109_1::NullError::Reason',
               'mutate/operations/operand/adExtension[ProductExtension]/productSelection/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'mutate/operations/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201109_1::SizeLimitError',
               'mutate/operations/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension' => 'Google::Ads::AdWords::v201109_1::AdExtension',
               'getResponse/rval/entries/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[ProductExtension]/productSelection/conditions/argument' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201109_1::LocationExtension',
               'mutate' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideService::mutate',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[ProductExtension]/productSelection/conditions/operand/operand' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutate/operations/operand/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[ProductExtension]/advertiserName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201109_1::ApiException',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::Status',
               'getResponse/rval/entries/adExtension[ProductExtension]/googleBaseCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201109_1::SizeLimitError::Reason',
               'mutate/operations/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideError',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201109_1::LocationExtension',
               'getResponse/rval/entries/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201109_1::LocationExtension',
               'mutateResponse/rval/value/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension' => 'Google::Ads::AdWords::v201109_1::AdExtension',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'mutate/operations/operand/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201109_1::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201109_1::RequestError::Reason',
               'mutate/operations/operand/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201109_1::LocationSyncExtension',
               'mutate/operations/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[ProductExtension]/advertiserName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201109_1::LocationOverrideInfo',
               'getResponse/rval/entries/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201109_1::LocationExtension::Source',
               'mutate/operations/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[ProductExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201109_1::OAuthInfo',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201109_1::ApiException',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[ProductExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201109_1::Sitelink',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideReturnValue',
               'mutate/operations/operand/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/approvalStatus' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::ApprovalStatus',
               'getResponse/rval/entries/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/approvalStatus' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride::ApprovalStatus',
               'mutateResponse/rval/value/overrideInfo' => 'Google::Ads::AdWords::v201109_1::OverrideInfo',
               'mutate/operations/operand/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/adExtension[ProductExtension]/productSelection' => 'Google::Ads::AdWords::v201109_1::ProductConditionAndGroup',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201109_1::RangeError::Reason',
               'mutate/operations/operand/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201109_1::RequestError',
               'get/selector/adExtensionIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201109_1::SitelinksExtension',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride',
               'mutateResponse/rval/value/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201109_1::RequiredError',
               'getResponse/rval/entries/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/overrideInfo' => 'Google::Ads::AdWords::v201109_1::OverrideInfo',
               'getResponse/rval/entries/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201109_1::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201109_1::NotEmptyError',
               'mutate/operations/operand/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201109_1::OperatorError',
               'mutate/operations/operand/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverride',
               'getResponse/rval/entries/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideSelector',
               'mutateResponse/rval/value/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations' => 'Google::Ads::AdWords::v201109_1::AdExtensionOverrideOperation',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201109_1::TypeMaps::AdExtensionOverrideService - typemap for AdExtensionOverrideService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

